Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(475)

Unified Diff: chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.cc

Issue 2449243002: Gtk3 ui: Add libgtk3ui as a separate build component (Closed)
Patch Set: Add theme_properties dep to //chrome/browser/ui Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.h ('k') | chrome/browser/ui/libgtkui/gtk2_signal.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.cc
diff --git a/chrome/browser/ui/libgtk2ui/gtk2_key_bindings_handler.cc b/chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.cc
similarity index 98%
rename from chrome/browser/ui/libgtk2ui/gtk2_key_bindings_handler.cc
rename to chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.cc
index dc967ae0351f715cdd674e207aadc50d5d2b2bb6..7abde41eca5c8c109c9264fa3f03c909b8e3f079 100644
--- a/chrome/browser/ui/libgtk2ui/gtk2_key_bindings_handler.cc
+++ b/chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/ui/libgtk2ui/gtk2_key_bindings_handler.h"
+#include "chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.h"
#include <gdk/gdkkeysyms.h>
#include <X11/Xlib.h>
@@ -14,7 +14,7 @@
#include "base/logging.h"
#include "base/macros.h"
#include "base/strings/string_util.h"
-#include "chrome/browser/ui/libgtk2ui/gtk2_util.h"
+#include "chrome/browser/ui/libgtkui/gtk2_util.h"
#include "content/public/browser/native_web_keyboard_event.h"
#include "ui/base/ime/text_edit_commands.h"
#include "ui/base/x/x11_util.h"
@@ -26,10 +26,10 @@ using ui::TextEditCommand;
// in a state that links. This code was adapted from the content layer GTK
// code, which had some simple unit tests. However, the changes in the public
// interface basically meant the tests need to be rewritten; this imposes weird
// linking requirements regarding GTK+ as we don't have a libgtk2ui_unittests
// yet. http://crbug.com/358297.
-namespace libgtk2ui {
+namespace libgtkui {
Gtk2KeyBindingsHandler::Gtk2KeyBindingsHandler()
: fake_window_(gtk_offscreen_window_new()),
@@ -436,4 +436,4 @@ void Gtk2KeyBindingsHandler::MoveFocus(GtkWidget* widget,
// Just for disabling the default handler.
}
-} // namespace libgtk2ui
+} // namespace libgtkui
« no previous file with comments | « chrome/browser/ui/libgtkui/gtk2_key_bindings_handler.h ('k') | chrome/browser/ui/libgtkui/gtk2_signal.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -26,10 +26,10 @@ using ui::TextEditCommand;
// code, which had some simple unit tests. However, the changes in the public
// interface basically meant the tests need to be rewritten; this imposes weird
-// linking requirements regarding GTK+ as we don't have a libgtk2ui_unittests
+// linking requirements regarding GTK+ as we don't have a libgtkui_unittests
// yet. http://crbug.com/358297.
This is Rietveld 408576698